# PyDBSP
<div align="center">
<a href="/assets/" />
<img src="/assets/logo.svg" width=400px" />
</a>
</div>

## Introduction
This library provides an implementation of the [DBSP](https://arxiv.org/pdf/2203.16684) language for incremental streaming
computation. It is a tool primarily meant for **research**. See it as the [PyTorch](https://github.com/pytorch/pytorch) of streaming.

## Examples
There are a myriad of examples living in each `test_*.py` file.
